marktools.get_marks_attached_to_component
=========================================

.. autofunction:: abjad.tools.marktools.get_marks_attached_to_component.get_marks_attached_to_component
   :noindex:
